@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-from B1 import B1, DatosActivacionBaja
+from __future__ import absolute_import, unicode_literals
+from .B1 import B1, DatosActivacionBaja
 from gestionatr.utils import get_rec_attr
 
 
